@@ -1,15 +1,13 @@
 import os
-
 from logging import Logger
 from pathlib import Path
 from typing import Generator, List, Union
 
 from gitlab import Gitlab
 from gitlab.base import RESTObject
-from gitlab.exceptions import GitlabListError
+from gitlab.exceptions import GitlabHttpError, GitlabListError
 from gitlab.v4.objects import Group, GroupVariable, Project, ProjectVariable
 
-
 Variable = Union[ProjectVariable, GroupVariable]
 
 
@@ -49,7 +47,7 @@ def save_environment_variables(
         for variable in variables:
             _save_environment_variable(variable, env_path)
 
-    except GitlabListError as e:
+    except (GitlabListError, GitlabHttpError) as e:
         logger.debug(e, exc_info=True)
         logger.debug(
             f"[Unable to save CI variables: {el_type} {element.name} "
@@ -77,7 +75,8 @@ def get_gitlab_element_type(element: RESTObject) -> str:
         return "project"
     else:
         raise NotImplementedError(
-            f"Got unsupported gitlab object type {type(element)}"
+            f"Got unsupported gitlab object type {type(element)}\n"
+            f"Excpected {Group} or {Project}"
         )
 
 
@@ -102,6 +101,7 @@ def get_gitlab_element_full_path(element: RESTObject) -> Path:
     else:
         raise NotImplementedError(
             f"Got unsupported gitlab object type {type(element)}"
+            f"Excpected {Group} or {Project}"
         )
 
 
